@@ -4,9 +4,6 @@
 #include <exception>
 #include <string>
 
-#include "r_interface/check_interrupt.h"
-#include "r_interface/error.h"
-
 #include "cpputil/Ptr.hpp"
 #include "r_interface/print_R_timestamp.hpp"
 #include "r_interface/handle_exception.hpp"
@@ -29,8 +26,6 @@
 #include "R.h"
 
 extern "C" {
-  using BOOM::RErrorReporter;
-  using BOOM::RCheckInterrupt;
   using namespace BOOM;  // NOLINT
 
   // This function is a wrapper for spike and slab regression.  It
